# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import openapi_client
from openapi_client.api.info_api import InfoApi  # noqa: E501
from openapi_client.rest import ApiException


class TestInfoApi(unittest.TestCase):
    """InfoApi unit test stubs"""

    def setUp(self):
        self.api = openapi_client.api.info_api.InfoApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_info_execution_types_get(self):
        """Test case for info_execution_types_get

        get list of possible execution types for jobs  # noqa: E501
        """
        pass

    def test_info_languages_get(self):
        """Test case for info_languages_get

        get list of languages in database  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
