# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import openapi_client
from openapi_client.api.device_rankings_api import DeviceRankingsApi  # noqa: E501
from openapi_client.rest import ApiException


class TestDeviceRankingsApi(unittest.TestCase):
    """DeviceRankingsApi unit test stubs"""

    def setUp(self):
        self.api = openapi_client.api.device_rankings_api.DeviceRankingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_devices_list_get(self):
        """Test case for devices_list_get

        retrieves list of potential devices to run the circuit on  # noqa: E501
        """
        pass

    def test_devices_list_stream_get(self):
        """Test case for devices_list_stream_get

        streams device detail updates  # noqa: E501
        """
        pass

    def test_devices_next_available_get(self):
        """Test case for devices_next_available_get

        retrieves list of next avaiable times for devices  # noqa: E501
        """
        pass

    def test_rankings_list_post(self):
        """Test case for rankings_list_post

        retrieves predicted device rankings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
